import React from "react";
import {X} from "@phosphor-icons/react";
import {useCurtain, useCurtains} from "../Curtains/Curtains";

/**
 * More natural name of useCurtains for subapps.
 * @see useCurtains
 */
export const useSubapps = useCurtains;

/**
 * More natural name of useCurtain for subapps.
 * @see useCurtain
 */
export const useSubapp = useCurtain;

/**
 * Subapp main component.
 */
export function Subapp({title, closable, children}: React.PropsWithChildren<{
	/**
	 * Subapp title.
	 */
	title?: string;

	/**
	 * Can disable close button.
	 */
	closable?: boolean;
}>)
{
	// Subapp is closable by default.
	closable = closable !== undefined ? closable : true;

	// Subapp state.
	const {close} = useSubapp();

	return (
		<div className={"subapp"}>
			<header>
				<h1>{title ?? ""}</h1>

				<button className={"icon-only close"} onClick={close} disabled={!closable}><X size={32}/></button>
			</header>

			<main>
				{children}
			</main>
		</div>
	);
}
